@@ -7,7 +7,7 @@ use Protocol::WebSocket::Handshake::Server;
 use Try::Tiny;
 use AnyEvent::WebSocket::Connection;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 sub new {
     my ($class, %args) = @_;
@@ -23,6 +23,7 @@ sub new {
     }
     my $self = bless {
         handshake => $handshake,
+        map { ($_ => $args{$_}) } qw(ssl_key_file ssl_cert_file),
     }, $class;
     return $self;
 }
@@ -39,9 +40,30 @@ sub _create_on_error {
     };
 }
 
+sub _handle_args_tls {
+    my ($self) = @_;
+    if(!defined($self->{ssl_key_file}) && !defined($self->{ssl_cert_file})) {
+        return ();
+    }
+    if(!defined($self->{ssl_cert_file})) {
+        croak "Only ssl_key_file is specified. You need to specify ssl_cert_file, too.";
+    }
+    return (
+        tls => "accept",
+        tls_ctx => {
+            cert_file => $self->{ssl_cert_file},
+            defined($self->{ssl_key_file}) ? (key_file => $self->{ssl_key_file}) : ()
+        }
+    );
+}
+
 sub _do_handshake {
-    my ($cv_connection, $fh, $handshake, $handshake_code) = @_;
-    my $handle = AnyEvent::Handle->new(fh => $fh, on_error => _create_on_error($cv_connection));
+    my ($self, $cv_connection, $fh, $handshake) = @_;
+    my $handshake_code = $self->{handshake};
+    my $handle = AnyEvent::Handle->new(
+        $self->_handle_args_tls,
+        fh => $fh, on_error => _create_on_error($cv_connection)
+    );
     my $read_cb = sub {
         ## We don't receive handle object as an argument here. $handle
         ## is imported in this closure so that $handle becomes
@@ -85,7 +107,7 @@ sub establish {
         return $cv_connection;
     }
     my $handshake = Protocol::WebSocket::Handshake::Server->new;
-    _do_handshake($cv_connection, $fh, $handshake, $self->{handshake});
+    $self->_do_handshake($cv_connection, $fh, $handshake);
     return $cv_connection;
 }
 
@@ -102,7 +124,7 @@ sub establish_psgi {
         return $cv_connection;
     }
     my $handshake = Protocol::WebSocket::Handshake::Server->new_from_psgi($env);
-    _do_handshake($cv_connection, $fh, $handshake, $self->{handshake});
+    $self->_do_handshake($cv_connection, $fh, $handshake);
     return $cv_connection;
 }
 
@@ -153,10 +175,6 @@ This class is an implementation of the WebSocket server in an L<AnyEvent> contex
 
 Currently this module supports WebSocket protocol version 13 only. See L<RFC 6455|https://tools.ietf.org/html/rfc6455> for detail.
 
-=item *
-
-Currently this module does not support SSL/TLS.
-
 =back
 
 
@@ -219,6 +237,22 @@ If you reject the C<$request>, throw an exception.
 If you accept the C<$request>, don't throw any exception.
 The return values of the C<$validator> are sent to the condition variable of C<establish()> method.
 
+=item C<ssl_key_file> => FILE_PATH (optional)
+
+A string of the filepath to the SSL/TLS private key file in PEM format.
+If you set this option, you have to set C<ssl_cert_file> option, too.
+
+If this option or C<ssl_cert_file> option is set, L<AnyEvent::WebSocket::Server> encrypts the WebSocket streams with SSL/TLS.
+
+=item C<ssl_cert_file> => FILE_PATH (optional)
+
+A string of the filepath to the SSL/TLS certificate file in PEM format.
+
+The file may contain both the certificate and corresponding private key. In that case, C<ssl_key_file> may be omitted.
+
+If this option is set, L<AnyEvent::WebSocket::Server> encrypts the WebSocket streams with SSL/TLS.
+
+
 =back
 
 
